local r_index_armor = {"uncommon", "rare", "epic"}
local r_index_weapon = {"common", "uncommon","rare", "epic", "legendary"} --"common", "uncommon", 
local q_index = {"poor", "fair", "good", "fine", "mint"} --"poor", "fair", "good", "fine", 
local sim_chances = {
	r = {65, 20, 10, 4, 1},
	q = {20, 20, 20, 20, 20},
	stat = 10
}

local function get_total(index, t)
	local total = 0
	for i, n in pairs(index) do
		total = total + (sim_chances[t][i])
	end
	return total
end

local function random_choice(index, t)
	local total = get_total(index, t)
	local rand_n = math.random(total)
	local track = 0
	for i, n in pairs(index) do
		local prob = sim_chances[t][i]
		if prob > 0 and rand_n > track and rand_n <= track + prob then
			return n
		end
		track = track + prob
	end
	return index[1]
end

local function choose_item(safe)
	local is_weapon = tweak_data.economy.contents[safe.content].contains.weapon_skins
	local r_index_over = is_weapon and safe.content == "overkill_01" and {"rare", "epic", "legendary"} or nil
	local data = {amount = 1, category = is_weapon and "weapon_skins" or "armor_skins"}
	local now = os.date("!*t")
	math.randomseed(now.yday * (now.hour + 1) * (now.min + 1) * (now.sec + 1))
	data.bonus = is_weapon and math.random(100) <= (sim_chances.stat)
	local rarity = random_choice(is_weapon and r_index_weapon or r_index_over or r_index_armor, "r")
	local skin_index = {}
	if rarity == "legendary" then
		local legend_contents = tweak_data.economy.contents[safe.content].contains.contents
		for _, skin in pairs(tweak_data.economy.contents[legend_contents[math.random(#legend_contents)]].contains[data.category]) do
			table.insert(skin_index, skin)
		end
	else
		local group = is_weapon and tweak_data.blackmarket.weapon_skins or tweak_data.economy.armor_skins
		for _, skin in pairs(tweak_data.economy.contents[safe.content].contains[data.category]) do
			if group[skin].rarity == rarity then
				table.insert(skin_index, skin)
			end
		end
	end
	data.entry = skin_index[math.random(#skin_index)]
	data.quality = is_weapon and random_choice(q_index, "q") or nil
	data.def_id = 101
	local i = 1
	while managers.blackmarket._global.inventory_tradable[tostring(i)] ~= nil do
		i = i + 1
	end
	data.instance_id = tostring(i)
	return data
end

local function start_open(name, data)
	local function ready_clbk()
		managers.menu:back()
		managers.system_menu:force_close_all()
		managers.menu_component:set_blackmarket_enabled(false)
		managers.menu:open_node("open_steam_safe", {data.content})
	end
	managers.menu_component:set_blackmarket_disable_fetching(true)
	managers.menu_component:set_blackmarket_enabled(false)
	managers.menu_scene:create_economy_safe_scene(name, ready_clbk)
	local item = choose_item(data)
	MenuCallbackHandler:_safe_result_recieved(nil, {item}, {})
	managers.blackmarket:tradable_add_item(item.instance_id, item.category, item.entry, item.quality, item.bonus, 1)
	managers.mission._fading_debug_output:script().log(string.format("ACTIVATED"),  Color.green)
end

local safe_menu = function()
	local dialog_data = {    
		title = "Safe Menu",
		text = "Select Option",
		button_list = {}
	}
	
	for safe, safe_d in pairs(tweak_data.economy.safes) do
		table.insert(dialog_data.button_list, {
			text = managers.localization:text(safe_d.name_id),
			callback_func = function() start_open(safe, safe_d) end,
		})
	end
	
	table.insert(dialog_data.button_list, {})
	local no_button = {text = managers.localization:text("dialog_cancel"), cancel_button = true}     
	table.insert(dialog_data.button_list, no_button) 
	managers.system_menu:show_buttons(dialog_data)
end
safe_menu()